==> v0.2.6.zip: siyuan/README.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>源于思考，饮水思源</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Release Date" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release-date/siyuan-note/siyuan.svg?style=flat-square&color=99CCFF"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README_en_US.md">English</a>
</p>

## 💡 简介

思源笔记是一款 Markdown 块级引用和双向链接的网状笔记应用，支持 Windows、Mac 和 Linux，可在浏览器上直接使用，支持移动端适配。

欢迎到[思源笔记官方讨论区](https://ld246.com/tag/siyuan)了解更多。

![desktop.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/desktop.png)

![mobile.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/mobile.png)

## ✨  特性

* **为 Markdown 而生**
  * 支持即时渲染，对熟悉 Typora 的用户应该不会感到陌生，理论上这是最优雅的 Markdown 编辑方式
  * 支持数学公式、图表、流程图、甘特图、时序图、五线谱等
  * 粘贴 HTML 自动转换为 Markdown
  * 配置 Markdown 解析渲染细节参数
* 内容块
  * 块级引用和双向链接
  * 文档关系图、全局关系图
  * 书签收藏
* 在浏览器上直接使用、支持移动端
* 层级标签
* 多窗口多页签，拖拽分屏
* WebDAV
* 版本管理、Git 仓库同步
* 全文搜索
* 主题和图标
  * 内置明亮、暗黑两套主题
  * 内置 Material、Ant Design 两套图标
  * 支持自定义主题和图标
* 导出
  * 标准 Markdown 导出
  * 内容块引用提供锚文本 + 嵌入 Blockquote 选项
  * 复制到微信公众号、知乎

## 🗺️ 路线图

* [思源笔记开发计划和进度](https://github.com/siyuan-note/siyuan/projects/1)
* [思源笔记版本变更记录](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 📸 截图

### 即时渲染

*即时渲染*模式对熟悉 Typora 的用户应该不会感到陌生，理论上这是最优雅的 Markdown 编辑方式。

![vditor-ir](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/ir.gif)

### 漫游

![roam.gif](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/roam.gif)

### 设置

![settings.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/settings.png)

### 搜索

![search.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/search.png)

### 内容块类型

![blocks.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/blocks.png)

### 块级引用

![blockref.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/block-ref.gif)

## 🛠️ 下载安装

* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [码云](https://gitee.com/siyuan-note/siyuan/releases)

## 📜 文档

* [思源笔记 - 支持 Markdown 块级引用和双向链接的网状笔记应用](https://ld246.com/article/1598872180233)
* [Markdown 实现块级引用双向链接的探索](https://ld246.com/article/1597226949061)

## 🏘️ 社区

* [思源笔记 Issues](https://github.com/siyuan-note/siyuan/issues)
* [思源笔记讨论区](https://ld246.com/tag/siyuan)
* [思源笔记 QQ 群](https://jq.qq.com/?_wv=1027&k=brIyNm7y)

## 🙏 鸣谢

* [浏览器端的编辑器 Vditor](https://github.com/Vanessa219/vditor)
* [对中文语境优化的 Markdown 引擎 Lute](https://github.com/88250/lute)
* [Go WebDAV 客户端库](https://github.com/88250/gowebdav)
* [Go 常用工具库](https://github.com/88250/gulu)
* [Go Web 框架 Gin](https://github.com/gin-gonic/gin)
* [Go WebSocket 框架 melody](https://github.com/olahol/melody)
* [跨平台桌面应用框架 Electron](https://github.com/electron/electron)

==> v0.4.1.zip: siyuan/README.md <==
<p align="center">
<img alt="SiYuan" src="https://b3log.org/images/brand/siyuan-128.png">
<br>
<em>源于思考，饮水思源</em>
<br><br>
<a title="Releases" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release/siyuan-note/siyuan.svg?style=flat-square&color=FF9900"></a>
<a title="Release Date" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/release-date/siyuan-note/siyuan.svg?style=flat-square&color=99CCFF"></a>
<a title="Downloads" target="_blank" href="https://github.com/siyuan-note/siyuan/releases"><img src="https://img.shields.io/github/downloads/siyuan-note/siyuan/total.svg?style=flat-square&color=blueviolet"></a>
<a title="Hits" target="_blank" href="https://github.com/siyuan-note/siyuan"><img src="https://hits.b3log.org/siyuan-note/siyuan.svg"></a>
</p>

<p align="center">
<a href="https://github.com/siyuan-note/siyuan/blob/master/README_en_US.md">English</a>
</p>

## 💡 简介

思源笔记是一款 Markdown 块级引用和双向链接的网状笔记应用，支持 Windows、Mac 和 Linux，可在浏览器上直接使用，支持移动端适配。

在线体验：[https://ld246.com/xanadu/](https://ld246.com/xanadu/)，欢迎到[思源笔记官方讨论区](https://ld246.com/tag/siyuan)了解更多。

![desktop.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/desktop.png)

![mobile.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/mobile.png)

## ✨  特性

* **为 Markdown 而生**
  * 支持即时渲染，对熟悉 Typora 的用户应该不会感到陌生，理论上这是最优雅的 Markdown 编辑方式
  * 支持数学公式、图表、流程图、甘特图、时序图、五线谱等
  * 粘贴 HTML 自动转换为 Markdown
  * 配置 Markdown 解析渲染细节参数
* 内容块
  * 块级引用和双向链接
  * 文档关系图、全局关系图
  * 书签收藏
* 在浏览器上直接使用、支持移动端
* 层级标签
* 多窗口多页签，拖拽分屏
* WebDAV
* 版本管理、Git 仓库同步
* 全文搜索
* 主题和图标
  * 内置明亮、暗黑两套主题
  * 内置 Material、Ant Design 两套图标
  * 支持自定义主题和图标
* 导出
  * 标准 Markdown 导出
  * 内容块引用提供锚文本 + 嵌入 Blockquote 选项
  * 复制到微信公众号、知乎

## 🗺️ 路线图

* [思源笔记开发计划和进度](https://github.com/siyuan-note/siyuan/projects/1)
* [思源笔记版本变更记录](https://github.com/siyuan-note/siyuan/blob/master/CHANGE_LOGS.md)

## 📸 截图

### 即时渲染

*即时渲染*模式对熟悉 Typora 的用户应该不会感到陌生，理论上这是最优雅的 Markdown 编辑方式。

![vditor-ir](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/ir.gif)

### 漫游

![roam.gif](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/roam.gif)

### 设置

![settings.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/settings.png)

### 搜索

![search.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/search.png)

### 块级引用

![blockref.png](https://cdn.jsdelivr.net/gh/siyuan-note/siyuan@master/screenshots/block-ref.gif)

## 🛠️ 下载安装

* [GitHub](https://github.com/siyuan-note/siyuan/releases)
* [码云](https://gitee.com/siyuan-note/siyuan/releases)

## 📜 文档

* [思源笔记 - 支持 Markdown 块级引用和双向链接的网状笔记应用](https://ld246.com/article/1598872180233)
* [Markdown 实现块级引用双向链接的探索](https://ld246.com/article/1597226949061)

## 🏘️ 社区

* [思源笔记 Issues](https://github.com/siyuan-note/siyuan/issues)
* [思源笔记讨论区](https://ld246.com/tag/siyuan)
* [思源笔记 QQ 群](https://jq.qq.com/?_wv=1027&k=brIyNm7y)

## 🙏 鸣谢

* [浏览器端的编辑器 Vditor](https://github.com/Vanessa219/vditor)
* [对中文语境优化的 Markdown 引擎 Lute](https://github.com/88250/lute)
* [Go WebDAV 客户端库](https://github.com/88250/gowebdav)
* [Go 常用工具库](https://github.com/88250/gulu)
* [Go Web 框架 Gin](https://github.com/gin-gonic/gin)
* [Go WebSocket 框架 melody](https://github.com/olahol/melody)
* [跨平台桌面应用框架 Electron](https://github.com/electron/electron)
